@@ -48,10 +48,6 @@
 #include "../xml/soap-1.1/soap_fault.h"
 #include "../utils.h"
 #include "../debug.h"
-#ifdef LASSO_WSF_ENABLED
-#include "../xml/idwsf_strings.h"
-#include "../xml/id-wsf-2.0/idwsf2_strings.h"
-#endif
 #include "../lasso_config.h"
 
 #include <stdio.h>
@@ -209,28 +205,6 @@ lasso_profile_get_request_type_from_soap_msg(const gchar *soap)
 		type = LASSO_REQUEST_TYPE_LECP;
 	} else if (strcmp(name, "ManageNameIDRequest") == 0) {
 		type = LASSO_REQUEST_TYPE_NAME_ID_MANAGEMENT;
-#ifdef LASSO_WSF_ENABLED
-	} else if (strcmp(name, "Query") == 0) {
-		if (strcmp((char*)ns->href, LASSO_DISCO_HREF) == 0) {
-			type = LASSO_REQUEST_TYPE_DISCO_QUERY;
-		} else if (strcmp((char*)ns->href, LASSO_IDWSF2_DISCOVERY_HREF) == 0) {
-			type = LASSO_REQUEST_TYPE_IDWSF2_DISCO_QUERY;
-		} else {
-			type = LASSO_REQUEST_TYPE_DST_QUERY;
-		}
-	} else if (strcmp(name, "Modify") == 0) {
-		if (strcmp((char*)ns->href, LASSO_DISCO_HREF) == 0) {
-			type = LASSO_REQUEST_TYPE_DISCO_MODIFY;
-		} else {
-			type = LASSO_REQUEST_TYPE_DST_MODIFY;
-		}
-	} else if (strcmp(name, "SASLRequest") == 0) {
-		type = LASSO_REQUEST_TYPE_SASL_REQUEST;
-	} else if (strcmp(name, "SvcMDRegister") == 0) {
-		type = LASSO_REQUEST_TYPE_IDWSF2_DISCO_SVCMD_REGISTER;
-	} else if (strcmp(name, "SvcMDAssociationAdd") == 0) {
-		type = LASSO_REQUEST_TYPE_IDWSF2_DISCO_SVCMD_ASSOCIATION_ADD;
-#endif
 	} else {
 		message(G_LOG_LEVEL_WARNING, "Unknown node name : %s", name);
 	}
