@@ -61,6 +61,10 @@
  * <entry><literal>no-sign-messages</literal></entry>
  * <entry><para>Disable signatures on messages.</para></entry>
  * </rows>
+ * <rows>
+ * <entry><literal>pem-public-key</literal></entry>
+ * <entry><para>Allow PEM key in ds:KeyValue nodes, it's outside the XMLSig specification.</para></entry>
+ * </rows>
  * </tbody>
  * </tgroup>
  * </informaltable>
@@ -72,6 +76,7 @@
 #include <string.h> /* strcmp */
 #include <xmlsec/xmlsec.h>
 #include <xmlsec/crypto.h>
+#include <xmlsec/errors.h>
 #include <libxslt/xslt.h>
 #include <config.h>
 #include "lasso.h"
@@ -96,11 +101,15 @@ static void lasso_flag_parse_environment_variable();
 gboolean lasso_flag_sign_messages = TRUE;
 /* thin sessions */
 gboolean lasso_flag_thin_sessions = FALSE;
+/* PEM public key */
+gboolean lasso_flag_pem_public_key = FALSE;
 
 #ifndef LASSO_FLAG_ENV_VAR
 #define LASSO_FLAG_ENV_VAR "LASSO_FLAG"
 #endif
 
+#define LASSO_DEFAULT_KEY_ENCRYPTION_METHOD_ENV_VAR "LASSO_DEFAULT_KEY_ENCRYPTION_METHOD"
+
 #if defined _MSC_VER
 HINSTANCE g_hModule = NULL;
 
@@ -129,13 +138,83 @@ DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
 #include "types.c"
 
 static void
-lasso_xml_generic_error_func(G_GNUC_UNUSED void *ctx, const char *msg, ...)
+lasso_xml_structured_error_func(G_GNUC_UNUSED void *user_data, xmlErrorPtr error)
 {
-	va_list args;
+	g_log("libxml2", G_LOG_LEVEL_DEBUG, "libxml2: %s", error->message);
+}
 
-	va_start(args, msg);
-	g_logv(LASSO_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, msg, args);
-	va_end(args);
+void
+lasso_xmlsec_errors_callback(const char *file G_GNUC_UNUSED, int line G_GNUC_UNUSED, const char *func G_GNUC_UNUSED,
+		const char *errorObject G_GNUC_UNUSED, const char *errorSubject G_GNUC_UNUSED, int reason G_GNUC_UNUSED,
+		const char *msg)
+{
+	g_log("libxmlsec", G_LOG_LEVEL_DEBUG, "libxmlsec: %s:%d:%s:%s:%s:%s:%s", file, line, func, errorObject, errorSubject, xmlSecErrorsGetMsg(reason), msg);
+}
+
+static int
+set_default_signature_method()
+{
+	int rv = LASSO_ERROR_UNDEFINED;
+
+	if (lasso_strisequal(DEFAULT_SIGNING_ALGO, "rsa-sha256")) {
+		lasso_set_default_signature_method(LASSO_SIGNATURE_METHOD_RSA_SHA256);
+		rv = 0;
+	} else if (lasso_strisequal(DEFAULT_SIGNING_ALGO, "rsa-sha1")) {
+		lasso_set_default_signature_method(LASSO_SIGNATURE_METHOD_RSA_SHA1);
+		rv = 0;
+	}
+
+	return rv;
+}
+
+static int
+set_min_allowed_hash_algo()
+{
+	int rv = LASSO_ERROR_UNDEFINED;
+
+	if (lasso_strisequal(MIN_HASH_ALGO, "sha1")) {
+		lasso_set_min_signature_method(LASSO_SIGNATURE_METHOD_RSA_SHA1);
+		rv = 0;
+	} else if (lasso_strisequal(MIN_HASH_ALGO, "sha256")) {
+		lasso_set_min_signature_method(LASSO_SIGNATURE_METHOD_RSA_SHA256);
+		rv = 0;
+	} else if (lasso_strisequal(MIN_HASH_ALGO, "sha384")) {
+		lasso_set_min_signature_method(LASSO_SIGNATURE_METHOD_RSA_SHA384);
+		rv = 0;
+	} else if (lasso_strisequal(MIN_HASH_ALGO, "sha512")) {
+		lasso_set_min_signature_method(LASSO_SIGNATURE_METHOD_RSA_SHA512);
+		rv = 0;
+	}
+
+	return rv;
+}
+
+static int
+set_default_key_encryption_method()
+{
+	char *env_encryption_sym_key_encryption_algo = getenv(LASSO_DEFAULT_KEY_ENCRYPTION_METHOD_ENV_VAR);
+	if (env_encryption_sym_key_encryption_algo) {
+		LassoKeyEncryptionMethod method = lasso_parse_key_encryption_method(
+			env_encryption_sym_key_encryption_algo);
+		if (method == -1) {
+			message(G_LOG_LEVEL_CRITICAL, "Unsupported key encryption "
+				"method %s configured in environment variable " LASSO_DEFAULT_KEY_ENCRYPTION_METHOD_ENV_VAR,
+				env_encryption_sym_key_encryption_algo);
+			return LASSO_ERROR_UNDEFINED;
+		}
+		lasso_set_default_key_encryption_method(method);
+		return 0;
+	}
+
+	LassoKeyEncryptionMethod method = lasso_parse_key_encryption_method(DEFAULT_KEY_ENCRYPTION_METHOD);
+	if (method != -1) {
+		lasso_set_default_key_encryption_method(method);
+		return 0;
+	} else {
+		message(G_LOG_LEVEL_CRITICAL, "Unsupported key encryption "
+			"method "DEFAULT_KEY_ENCRYPTION_METHOD" configured");
+		return LASSO_ERROR_UNDEFINED;
+	}
 }
 
 /**
@@ -153,6 +232,22 @@ int lasso_init()
 	g_type_init();
 #endif
 
+	/* Set the default hash algo */
+	if (set_default_signature_method() != 0) {
+		message(G_LOG_LEVEL_CRITICAL, "Unsupported signature "
+			"algorithm "DEFAULT_SIGNING_ALGO" configured");
+		return LASSO_ERROR_UNDEFINED;
+	}
+	if (set_min_allowed_hash_algo() != 0) {
+		message(G_LOG_LEVEL_CRITICAL, "Unsupported hash algorithm "
+			"algorithm "MIN_HASH_ALGO" configured");
+		return LASSO_ERROR_UNDEFINED;
+	}
+
+	if (set_default_key_encryption_method() != 0) {
+		return LASSO_ERROR_UNDEFINED;
+	}
+
 	/* Init Lasso classes */
 	for (i=0; functions[i]; i++)
 		functions[i]();
@@ -196,7 +291,8 @@ int lasso_init()
 		return LASSO_ERROR_UNDEFINED;
 	}
 	lasso_flag_parse_environment_variable();
-	xmlSetGenericErrorFunc(NULL, lasso_xml_generic_error_func);
+	xmlSetStructuredErrorFunc(NULL, lasso_xml_structured_error_func);
+	xmlSecErrorsSetCallback(lasso_xmlsec_errors_callback);
 	return 0;
 }
 
@@ -323,6 +419,9 @@ void lasso_set_flag(char *flag) {
 		if (lasso_strisequal(flag,"thin-sessions")) {
 			lasso_flag_thin_sessions = value;
 		}
+		if (lasso_strisequal(flag,"pem-public-key")) {
+			lasso_flag_pem_public_key = value;
+		}
 	} while (FALSE);
 }
 
@@ -339,3 +438,20 @@ static void lasso_flag_parse_environment_variable() {
 		} while ((token = strtok_r(NULL, delim, &save_ptr)) != NULL);
 	}
 }
+
+/* Deprecated functions, kept only to maintain the ABI and the SONAME */
+void lasso_register_dst_service(const char *prefix, const char *href)
+{
+}
+
+char* lasso_get_prefix_for_dst_service_href(const char *href)
+{
+	return NULL;
+}
+void lasso_register_idwsf2_dst_service(const gchar *prefix, const gchar *href)
+{
+}
+gchar* lasso_get_prefix_for_idwsf2_dst_service_href(const gchar *href)
+{
+	return NULL;
+}
